==> haskell-vector-sized-1.5.0-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-sized
version:              1.5.0
visibility:           public
id:                   vector-sized-1.5.0-CkbnkMmjohD447RC6A5BDf
key:                  vector-sized-1.5.0-CkbnkMmjohD447RC6A5BDf
license:              BSD-3-Clause
copyright:            2016 Joe Hermaszewski
maintainer:           whats.our.vector.victor@monoid.al
author:               Joe Hermaszewski
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  1b77e3dfb50e5cf2a70a86b8805815de
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

hidden-modules:       Paths_vector_sized
import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-sized-1.5.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-sized-1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/vector-sized-1.5.0
hs-libraries:         HSvector-sized-1.5.0-CkbnkMmjohD447RC6A5BDf
depends:
    adjunctions-4.4-3sSXZmL7FR3NlodAyVh9V base-4.15.1.0 binary-0.8.8.0
    comonad-5.0.8-Iw3JPjGiSsJKsuEFaLKabc deepseq-1.4.5.0
    distributive-0.6.2.1-9PWYQcLFLjaExrKJhLprZG
    finite-typelits-0.1.4.2-HkweRlPkyRp1DlFbnQ8avR
    hashable-1.4.0.0-LbiCNO5gyl3FzQI198nxBm
    indexed-list-literals-0.2.1.3-LeGzkCXYEXT1oEuBZirk8q
    primitive-0.7.3.0-54yhKl7GYKVF2i3EyCYoxq
    vector-0.12.3.1-FGR30quEvBKIVgcX0eclul

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-sized-1.5.0-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-sized
version:              1.5.0
visibility:           public
id:                   vector-sized-1.5.0-JwjPbQRE9ScHrp3uCkUB8C
key:                  vector-sized-1.5.0-JwjPbQRE9ScHrp3uCkUB8C
license:              BSD-3-Clause
copyright:            2016 Joe Hermaszewski
maintainer:           whats.our.vector.victor@monoid.al
author:               Joe Hermaszewski
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  90ca06d7af4d78a050736177bc219d9d
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

hidden-modules:       Paths_vector_sized
import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-sized-1.5.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-sized-1.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/vector-sized-1.5.0
hs-libraries:         HSvector-sized-1.5.0-JwjPbQRE9ScHrp3uCkUB8C
depends:
    adjunctions-4.4-697SsS16oZV23oQaUgIrpY base-4.15.1.0 binary-0.8.8.0
    comonad-5.0.8-KwwxB99WyimCiGW0BLNTzV deepseq-1.4.5.0
    distributive-0.6.2.1-4izjp7ecaFr3MYVmyQDC1a
    finite-typelits-0.1.4.2-HkweRlPkyRp1DlFbnQ8avR
    hashable-1.4.0.0-1WceaWFbireGDX0CpHAq2k
    indexed-list-literals-0.2.1.3-c9rjEavAns3Ofy5gWNZrZ
    primitive-0.7.3.0-7AJPDoiGmkKGBEfxag6csc
    vector-0.12.3.1-5HK1DqtCbep8rMk53O5plV

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
